PCB Environment: ObjectsBVH Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions
ObjectsBVH Class Referenceabstract

## Public Member Functions
virtual void | select (std::set< Object * > &, const Bbox_2 &, uint zmin=0, uint zmax=~0u) const =0
virtual Object * | select (const Point_2 &, int z) const =0
Object * | select (const Point_25 &x) const
virtual void | insert (Object &)=0

## Static Public Member Functions
static ObjectsBVH * | create ()

## Member Function Documentation

## ◆ select() [1/2]

virtual Object * ObjectsBVH::select | ( | const Point_2 & | ,
|  | int | z ) const
| pure virtual

Select the deepest (child) object at the specified point.

## ◆ select() [2/2]

virtual void ObjectsBVH::select | ( | std::set< Object * > & | ,
|  | const Bbox_2 & | ,
|  | uint | zmin = 0,
|  | uint | zmax = ~0u ) const
| pure virtual

Add objects within the bounding area to the set container.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/BVH.hpp